@@ -11,9 +11,9 @@ from .utils import Arrows
 
 from manim.mobject.types.vectorized_mobject import VGroup, VMobject
 from manim.mobject.svg.tex_mobject import *
-from manim.animation.fading import FadeInFrom
 from manim.animation.animation import Animation
 from manim.animation.creation import Write
+from manim.animation.fading import FadeIn
 from manim.animation.composition import AnimationGroup
 from manim.mobject.geometry import DashedLine
 from manim.constants import *
@@ -424,15 +424,17 @@ class Reaction(Tex):
     def creation_anim(
         self,
         text_anim: Animation = Write,
-        arrow_anim: Animation = FadeInFrom,
+        arrow_anim: Animation = FadeIn,
         reactant_product_simultaneity=False,
-        **kwargs,
+        text_anim_kwargs: dict = None,
+        arrow_anim_kwargs: dict = None,
+        group_anim_kwargs: dict = None,
     ) -> AnimationGroup:
         """Workaround and shortcut method to overcome the bugs in `Write`.
 
         Args:
             text_anim (Animation, optional): The animation on the reactants and products. Defaults to Write.
-            arrow_anim (Animation, optional): The animation on the arrow. Defaults to FadeInFrom.
+            arrow_anim (Animation, optional): The animation on the arrow. Defaults to FadeIn.
             reactant_product_simultaneity (bool, optional): Whether to animate the reactants and products together or not.
         Returns:
             AnimationGroup: The group of animations on the text and arrow.
@@ -442,108 +444,83 @@ class Reaction(Tex):
         )
         arrow = self[2 * len(self.reactants) - 1]
 
-        if "text_kwargs" not in kwargs.keys():
-            kwargs["text_kwargs"] = dict()
+        if text_anim_kwargs is None:
+            text_anim_kwargs = dict()
 
-        if "arrow_kwargs" not in kwargs.keys():
-            kwargs["arrow_kwargs"] = dict()
+        if arrow_anim_kwargs is None:
+            arrow_anim_kwargs = dict()
 
-        if "group_kwargs" not in kwargs.keys():
-            kwargs["group_kwargs"] = dict()
-
-        print(kwargs["group_kwargs"])
+        if group_anim_kwargs is None:
+            group_anim_kwargs = dict()
 
         anim_group = (
             AnimationGroup(
-                text_anim(text[0]), text_anim(text[1]), arrow_anim(arrow), **kwargs
+                text_anim(text[0], **text_anim_kwargs),
+                text_anim(text[1], **text_anim_kwargs),
+                arrow_anim(arrow, **arrow_anim_kwargs),
+                **group_anim_kwargs,
             )
             if reactant_product_simultaneity
-            else AnimationGroup(text_anim(text), arrow_anim(arrow), **kwargs)
+            else AnimationGroup(
+                text_anim(text, **text_anim_kwargs),
+                arrow_anim(arrow, **arrow_anim_kwargs),
+                **group_anim_kwargs,
+            )
         )
 
-        try:
-            print(anim_group.run_time)
-        except Exception:
-            pass
         return anim_group
 
 
 class ChemArrow(MathTex):
     """
-    `chanimlib.chem_objects.ChemArrow`
     Chemical Reaction Arrow
     =======================
     Basically a Reaction without any reactants/products.
 
-    May change later.
+    Arguments:
+    ----------
+
+    mode: Arrows - The type of arrow to be used. See :class:`Arrows` for more info on available options.
+
+    length - length of the arrow. Sets `arrow coeff` chemfig property.
+
+    angle - angle made with respect to the x-axis. Sets `arrow angle` chemfig property.
+
+    style - Single string of comma separated TiKZ styling parameters. Sets `arrow style` chemfig property.
+
+    text_up - text to be displayed above the main arrow line.
+
+    text_down - text to be displayed below the main arrow line.
+
+
     """
 
-    # CONFIG = {
-    #     "stroke_width": 2,
-    # }
-
-    arrows = {
-        "forward": "->",
-        "backward": "<-",
-        "eq": "<=>",
-        "eq_fw": "<->>",
-        "eq_bw": "<<->",
-        "double": "<->",
-        "space": "0",
-        "split": "-U>",
-    }
-
     def __init__(
         self,
-        _type="forward",
+        mode=Arrows.forward,
         length=1,
         angle=0,
-        style="{}",
+        style="",
         text_up="",
         text_down="",
         stroke_width=2,
+        tex_template=ChemReactionTemplate,
         **kwargs,
     ):
-        # digest_config(self, kwargs)
-        set_chemfig = """\\setchemfig{atom sep=2em,
-                                      arrow angle={%d},
-                                      arrow coeff={%s},
-                                      arrow style=%s }""" % (
-            angle,
-            length,
-            style,
+        self.tex_template: ChemReactionTemplate = tex_template()
+
+        self.tex_template.set_chemfig(
+            arrow_angle=angle, arrow_length=length, arrow_style=style
         )
-        self.template_tex_file_body = self.template_tex_file_body.replace(
-            "\\setchemfig{atom sep=2em}", f"{set_chemfig}"
+        arrow = "\\arrow{%s[%s][%s]}" % (mode.value, text_up, text_down)
+        MathTex.__init__(
+            self,
+            arrow,
+            stroke_width=stroke_width,
+            tex_template=self.tex_template,
+            **kwargs,
         )
 
-        arrow = "\\arrow{%s[%s][%s]}" % (self.arrows[_type], text_up, text_down)
-        MathTex.__init__(self, arrow, stroke_width=stroke_width, **kwargs)
-
-
-class ChemName(MathTex):
-    """`chanimlib.chem_objects.ChemName`
-
-    An attempt to use chemfig's \\chemname{} macro.
-
-    This will only be written in one go, so if you'd like
-    animations for both parts see `ChemWithName`.
-
-    NOTE: To be deprecated. Use `ChemWithName` instead
-    """
-
-    # CONFIG = {"stroke_width": 2}
-
-    def __init__(self, chem, name, buff=1, stroke_width=2, **kwargs):
-        # digest_config(self, kwargs)
-
-        chem_with_name = "\\chemname[%sem]{\\chemfig{%s}}{%s}" % (buff, chem, name)
-        # self.template_tex_file_body = TEMPLATE_CHEM_FILE_BODY.replace(
-        #     "\\chemfig{",
-        #     chem_with_name)
-
-        MathTex.__init__(self, chem_with_name, stroke_width=stroke_width, **kwargs)
-
 
 class ChemWithName(VMobject):
     """
@@ -588,9 +565,24 @@ class ChemWithName(VMobject):
         self.submobjects = [self.chem, self.name]
 
     def creation_anim(
-        self, chem_anim: Animation = Write, name_anim: Animation = FadeInFrom
+        self,
+        chem_anim: Animation = Write,
+        name_anim: Animation = FadeIn,
+        chem_anim_kwargs=None,
+        name_anim_kwargs=None,
+        group_anim_kwargs=None,
     ):
-        return AnimationGroup(chem_anim(self.chem), name_anim(self.name))
+        if chem_anim_kwargs is None:
+            chem_anim_kwargs = dict()
+
+        if name_anim_kwargs is None:
+            name_anim_kwargs = dict()
+
+        return AnimationGroup(
+            chem_anim(self.chem, **chem_anim_kwargs),
+            name_anim(self.name, **name_anim_kwargs),
+            **group_anim_kwargs,
+        )
 
 
 class ChemAbove(ChemObject):
